==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Hemsida', # MODIF
	'articles' => 'Artiklar',
	'articles_auteur' => 'Författarens artiklar',
	'articles_populaires' => 'De mest lästa artiklarna',
	'articles_rubrique' => 'Avdelningens artiklar',
	'aucun_article' => 'Det finns ingen artikel på denna adress',
	'aucun_auteur' => 'Det finns ingen författare på denna adress',
	'aucun_site' => 'Det finns ingen sajt på denna adress',
	'aucune_breve' => 'Det finns ingen nyhet på denna adress',
	'aucune_rubrique' => 'Det finns ingen avdelning på denna adress',
	'autres' => 'Andra',
	'autres_breves' => 'Andra nyheter',
	'autres_groupes_mots_clefs' => 'Andra grupper av nyckelord',
	'autres_sites' => 'Andra sajter',

	// B
	'bonjour' => 'Hej',

	// C
	'commenter_site' => 'Kommentera sajten',
	'copie_document_impossible' => 'Det går inte att kopiera dokumentet',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Senaste bidragen',
	'dernieres_breves' => 'Senaste nyheterna',
	'derniers_articles' => 'Senaste artiklarna',
	'derniers_commentaires' => 'Senaste kommentarerna',
	'derniers_messages_forum' => 'Senaste forum-meddelandena',

	// E
	'edition_mode_texte' => 'Textversion',
	'en_reponse' => 'Svarar på:',
	'en_resume' => 'Sammanfattning',
	'envoyer_message' => 'För att skicka ett meddelande',
	'espace_prive' => 'Privat del',

	// F
	'formats_acceptes' => 'Godkända format: @formats@.',

	// H
	'hierarchie_site' => 'Sajtens hierarki',

	// J
	'jours' => 'dagar',

	// L
	'lien_connecter' => 'Logga in',

	// M
	'meme_auteur' => 'Av samma författare',
	'meme_rubrique' => 'Inom samma avdelning',
	'memes_auteurs' => 'Av samma författare',
	'message' => 'Meddelande',
	'messages_forum' => 'Forum-meddelande', # MODIF
	'messages_recents' => 'Senaste forum-meddelandena',
	'mots_clefs' => 'Nyckelord',
	'mots_clefs_meme_groupe' => 'Nyckelord i samma grupp',

	// N
	'navigation' => 'Navigering',
	'nom' => 'Namn',
	'nouveautes' => 'Nytt',
	'nouveautes_web' => 'Nytt på webben',
	'nouveaux_articles' => 'Nya artiklar',
	'nouvelles_breves' => 'Nya nyheter',

	// P
	'page_precedente' => 'föregående sida',
	'page_suivante' => 'nästa sida',
	'par_auteur' => 'av ',
	'participer_site' => 'Du kan ta en aktiv roll i den här sajten och skriva dina egna artiklar genom att registrera dig nedan. Du kommer då genast att få ett epost med uppgifter som du använder för att logga in på sajtens privata del.',
	'plan_site' => 'Sajtkarta',
	'popularite' => 'Popularitet',
	'poster_message' => 'För att skicka ett meddelande',
	'proposer_site' => 'Du kan föreslå en sajt att lägga till i avdelningen:',

	// R
	'repondre_article' => 'Svara på artikeln',
	'repondre_breve' => 'Svara på nyheten',
	'resultats_recherche' => 'Sök-resultat',
	'retour_debut_forums' => 'Tillbaka till forumens början',
	'rubrique' => 'Avdelning',
	'rubriques' => 'Avdelningar',

	// S
	'signatures_petition' => 'Underskrifter',
	'site_realise_avec_spip' => 'Sajten skapad med SPIP',
	'sites_web' => 'Websajter',
	'sous_rubriques' => 'Underavdelningar',
	'spam' => 'Spam',
	'suite' => 'fortsätt',
	'sur_web' => 'På webben',
	'syndiquer_rubrique' => 'Syndikera avdelning',
	'syndiquer_site' => 'Syndikera hela sajten',

	// T
	'texte_lettre_information' => 'Här är sajtens nyhetsbrev',
	'texte_lettre_information_2' => 'Det här brevet innehåller en sammanfattning av de artiklar och nyheter som publicerats sedan ', # MODIF

	// V
	'ver_imprimer' => 'Utskrifts-version',
	'voir_en_ligne' => 'Se online',
	'voir_squelette' => 'visa sidans mall'
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/lang/public_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=sv
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Hemsida', # MODIF
	'articles' => 'Artiklar',
	'articles_auteur' => 'Författarens artiklar',
	'articles_populaires' => 'De mest lästa artiklarna',
	'articles_rubrique' => 'Avdelningens artiklar',
	'aucun_article' => 'Det finns ingen artikel på denna adress',
	'aucun_auteur' => 'Det finns ingen författare på denna adress',
	'aucun_site' => 'Det finns ingen sajt på denna adress',
	'aucune_breve' => 'Det finns ingen nyhet på denna adress',
	'aucune_rubrique' => 'Det finns ingen avdelning på denna adress',
	'autres' => 'Andra',
	'autres_breves' => 'Andra nyheter',
	'autres_groupes_mots_clefs' => 'Andra grupper av nyckelord',
	'autres_sites' => 'Andra sajter',

	// B
	'bonjour' => 'Hej',

	// C
	'commenter_site' => 'Kommentera sajten',
	'copie_document_impossible' => 'Det går inte att kopiera dokumentet',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Senaste bidragen',
	'dernieres_breves' => 'Senaste nyheterna',
	'derniers_articles' => 'Senaste artiklarna',
	'derniers_commentaires' => 'Senaste kommentarerna',
	'derniers_messages_forum' => 'Senaste forum-meddelandena',

	// E
	'edition_mode_texte' => 'Textversion',
	'en_reponse' => 'Svarar på:',
	'en_resume' => 'Sammanfattning',
	'envoyer_message' => 'För att skicka ett meddelande',
	'espace_prive' => 'Privat del',

	// F
	'formats_acceptes' => 'Godkända format: @formats@.',

	// H
	'hierarchie_site' => 'Sajtens hierarki',

	// J
	'jours' => 'dagar',

	// L
	'lien_connecter' => 'Logga in',

	// M
	'meme_auteur' => 'Av samma författare',
	'meme_rubrique' => 'Inom samma avdelning',
	'memes_auteurs' => 'Av samma författare',
	'message' => 'Meddelande',
	'messages_forum' => 'Forum-meddelande', # MODIF
	'messages_recents' => 'Senaste forum-meddelandena',
	'mots_clefs' => 'Nyckelord',
	'mots_clefs_meme_groupe' => 'Nyckelord i samma grupp',

	// N
	'navigation' => 'Navigering',
	'nom' => 'Namn',
	'nouveautes' => 'Nytt',
	'nouveautes_web' => 'Nytt på webben',
	'nouveaux_articles' => 'Nya artiklar',
	'nouvelles_breves' => 'Nya nyheter',

	// P
	'page_precedente' => 'föregående sida',
	'page_suivante' => 'nästa sida',
	'par_auteur' => 'av ',
	'participer_site' => 'Du kan ta en aktiv roll i den här sajten och skriva dina egna artiklar genom att registrera dig nedan. Du kommer då genast att få ett epost med uppgifter som du använder för att logga in på sajtens privata del.',
	'plan_site' => 'Sajtkarta',
	'popularite' => 'Popularitet',
	'poster_message' => 'För att skicka ett meddelande',
	'proposer_site' => 'Du kan föreslå en sajt att lägga till i avdelningen:',

	// R
	'repondre_article' => 'Svara på artikeln',
	'repondre_breve' => 'Svara på nyheten',
	'resultats_recherche' => 'Sök-resultat',
	'retour_debut_forums' => 'Tillbaka till forumens början',
	'rubrique' => 'Avdelning',
	'rubriques' => 'Avdelningar',

	// S
	'signatures_petition' => 'Underskrifter',
	'site_realise_avec_spip' => 'Sajten skapad med SPIP',
	'sites_web' => 'Websajter',
	'sous_rubriques' => 'Underavdelningar',
	'spam' => 'Spam',
	'suite' => 'fortsätt',
	'sur_web' => 'På webben',
	'syndiquer_rubrique' => 'Syndikera avdelning',
	'syndiquer_site' => 'Syndikera hela sajten',

	// T
	'texte_lettre_information' => 'Här är sajtens nyhetsbrev',
	'texte_lettre_information_2' => 'Det här brevet innehåller en sammanfattning av de artiklar och nyheter som publicerats sedan ', # MODIF

	// V
	'ver_imprimer' => 'Utskrifts-version',
	'voir_en_ligne' => 'Se online',
	'voir_squelette' => 'visa sidans mall',
];
